@@ -7,11 +7,9 @@ import platform
 import textwrap
 import json
 import signal
-from contextlib import redirect_stdout
-import io
 import ast
 
-__version__ = '0.5.0'
+__version__ = '1.0.0'
 
 
 def ctrlc(signum, frame):
@@ -41,11 +39,11 @@ def helptext():
                 -v    version info
                 -h    help
 
-        Use '_' as the input data and assign the result to 'r'. Use python dict syntax.
+        Use '_' as the input data and use python dict and list syntax.
 
         Example:
-                <JSON Data> | jello 'r = _["foo"]'
-                variable=($(cat data.json | jello -l 'r = _["foo"]'))
+                <JSON Data> | jello '_["foo"]'
+                variable=($(cat data.json | jello -l '_["foo"]'))
     '''))
 
 
@@ -68,6 +66,12 @@ def create_json(data, compact=False, nulls=None, lines=None, raw=None):
             return json.dumps(data, indent=2)
 
     if isinstance(data, list):
+        if not lines:
+            if compact:
+                return json.dumps(data)
+            else:
+                return json.dumps(data, indent=2)
+
         # check if this list includes lists
         list_includes_list = False
         for item in data:
@@ -75,28 +79,7 @@ def create_json(data, compact=False, nulls=None, lines=None, raw=None):
                 list_includes_list = True
                 break
 
-        if not lines and not list_includes_list:
-            new_list = []
-
-            for entry in data:
-                if isinstance(entry, str):
-                    new_list.append(entry.replace('\u2063', '\n'))
-                else:
-                    new_list.append(entry)
-
-            if compact:
-                return json.dumps(new_list)
-
-            else:
-                return json.dumps(new_list, indent=2)
-
-        if not lines:
-            if compact:
-                return json.dumps(data)
-            else:
-                return json.dumps(data, indent=2)
-
-        elif lines and list_includes_list:
+        if lines and list_includes_list:
             print_error('jello:  Cannot print list of lists as lines. Try normal JSON output.\n')
 
         # print lines for a flat list
@@ -109,22 +92,16 @@ def create_json(data, compact=False, nulls=None, lines=None, raw=None):
                     else:
                         flat_list += '\n'
 
-                elif entry is True:
-                    flat_list += 'true\n'
-
-                elif entry is False:
-                    flat_list += 'false\n'
+                elif isinstance(entry, (dict, bool, int, float)):
+                    flat_list += json.dumps(entry) + '\n'
 
                 elif isinstance(entry, str):
-                    string_data = entry.replace('\u2063', r'\n')
+                    # replace \n with \\n here so lines with newlines literally print the \n char
+                    entry = entry.replace('\n', '\\n')
                     if raw:
-                        flat_list += f'{string_data}\n'
+                        flat_list += f'{entry}' + '\n'
                     else:
-                        flat_list += f'"{string_data}"\n'
-
-                else:
-                    # don't pretty print JSON Lines
-                    flat_list += json.dumps(entry) + '\n'
+                        flat_list += f'"{entry}"' + '\n'
 
             return flat_list.rstrip()
 
@@ -135,76 +112,16 @@ def create_json(data, compact=False, nulls=None, lines=None, raw=None):
         else:
             return ''
 
-    elif data is True:
-        return 'true'
-
-    elif data is False:
-        return 'false'
-
-    elif isinstance(data, (int, float)):
-        return data
+    elif isinstance(data, (bool, int, float)):
+        return json.dumps(data)
 
     elif isinstance(data, str):
-        string_data = data.replace('\u2063', r'\n')
+        # replace \n with \\n here so lines with newlines literally print the \n char
+        data = data.replace('\n', '\\n')
         if raw:
-            return string_data
+            return f'{data}'
         else:
-            return f'"{string_data}"'
-
-
-def normalize(data, nulls=None, raw=None):
-    result_list = []
-
-    # first check if it's a dict
-    try:
-        if isinstance(ast.literal_eval(data), dict):
-            return ast.literal_eval(data.replace(r'\u2063', r'\n'))
-    except Exception:
-        # was not a dict
-        pass
-
-    try:
-        for entry in data.splitlines():
-            # check if the result is a single list with no dicts or other lists inside
-            try:
-                list_includes_obj = False
-                check_list = ast.literal_eval(entry)
-                if isinstance(check_list, list):
-                    for item in check_list:
-                        if isinstance(item, (list, dict)):
-                            list_includes_obj = True
-                            break
-
-                if list_includes_obj:
-                    # this is a higher-level list of dicts or lists. We can safely replace
-                    # \u2063 with newlines here.
-                    result_list.append(ast.literal_eval(entry.replace(r'\u2063', r'\n')))
-                else:
-                    # this is the last node. Don't replace \u2063 with newline yet...
-                    # do this in print_json()
-                    result_list.append(check_list)
-
-            except (ValueError, SyntaxError):
-                # if ValueError or SyntaxError exception then it was not a
-                # list, dict, bool, None, int, or float - must be a string
-                # we will replace \u2063 with newlines in print_json()
-                result_list.append(str(entry))
-
-    except Exception as e:
-        print_error(textwrap.dedent(f'''\
-            jello:  Normalize Exception: {e}
-                    data: {data}
-                    result_list: {result_list}
-            '''))
-
-    try:
-        return result_list[0]
-
-    except IndexError as e:
-        print_error(textwrap.dedent(f'''\
-            jello:  Normalize Exception: {e}
-                    Cannot parse input (Not JSON or JSON Lines)
-        '''))
+            return f'"{data}"'
 
 
 def pyquery(data, query, initialize=None):
@@ -218,21 +135,30 @@ def pyquery(data, query, initialize=None):
             conf_file = os.path.join(os.environ["HOME"], '.jelloconf.py')
 
         try:
-            with open(conf_file, 'r') as f: 
+            with open(conf_file, 'r') as f:
                 jelloconf = f.read()
         except FileNotFoundError:
             print_error(textwrap.dedent(f'''\
                 jello:  Initialization file not found: {conf_file}
             '''))
 
-    query = jelloconf + 'r = None\n' + query + '\nprint(r)'
+    query = jelloconf + query
     output = None
 
-    f = io.StringIO()
+    # f = io.StringIO()
+    # try:
+    #     with redirect_stdout(f):
+    #         print(exec(compile(query, '<string>', 'exec')))
+    #         output = f.getvalue()[0:-6]
+
     try:
-        with redirect_stdout(f):
-            print(exec(compile(query, '<string>', 'exec')))
-            output = f.getvalue()[0:-6]
+        block = ast.parse(query, mode='exec')
+
+        # assumes last node is an expression
+        last = ast.Expression(block.body.pop().value)
+
+        exec(compile(block, '<string>', mode='exec'))
+        output = eval(compile(last, '<string>', mode='eval'))
 
     except KeyError as e:
         print_error(textwrap.dedent(f'''\
@@ -258,6 +184,16 @@ def pyquery(data, query, initialize=None):
                 jello:  TypeError: {e}
             '''))
 
+    except AttributeError as e:
+        print_error(textwrap.dedent(f'''\
+            jello:  AttributeError: {e}
+        '''))
+
+    except NameError as e:
+        print_error(textwrap.dedent(f'''\
+            jello:  NameError: {e}
+        '''))
+
     except Exception as e:
         print_error(textwrap.dedent(f'''\
             jello:  Query Exception: {e}
@@ -270,10 +206,6 @@ def pyquery(data, query, initialize=None):
 
 
 def load_json(data):
-    # replace newline characters in the input text with unicode separator \u2063
-    data = data.strip().replace(r'\n', '\u2063')
-
-    # load the JSON or JSON Lines data
     try:
         json_dict = json.loads(data)
 
@@ -298,7 +230,7 @@ def load_json(data):
     return json_dict
 
 
-def main(data=None, query='r = _', compact=None, lines=None, nulls=None, raw=None, version_info=None, helpme=None, initialize=None):
+def main(data=None, query='_', compact=None, lines=None, nulls=None, raw=None, version_info=None, helpme=None, initialize=None):
     # break on ctrl-c keyboard interrupt
     signal.signal(signal.SIGINT, ctrlc)
 
@@ -350,9 +282,8 @@ def main(data=None, query='r = _', compact=None, lines=None, nulls=None, raw=Non
         lines_warning = True
 
     list_dict_data = load_json(data)
-    raw_response = pyquery(list_dict_data, query, initialize=initialize)
-    normalized_response = normalize(raw_response, raw=raw, nulls=nulls)
-    output = create_json(normalized_response, compact=compact, nulls=nulls, raw=raw, lines=lines)
+    response = pyquery(list_dict_data, query, initialize=initialize)
+    output = create_json(response, compact=compact, nulls=nulls, raw=raw, lines=lines)
 
     try:
         if commandline:
@@ -364,8 +295,7 @@ def main(data=None, query='r = _', compact=None, lines=None, nulls=None, raw=Non
         print_error(textwrap.dedent(f'''\
             jello:  Output Exception:  {e}
                     list_dict_data: {list_dict_data}
-                    raw_response: {raw_response}
-                    normalized_response: {normalized_response}
+                    response: {response}
                     output: {output}
         '''))
 
